==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/CustomFeatureGatesFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public class CustomFeatureGatesFluentImpl<A extends io.fabric8.openshift.api.model.CustomFeatureGatesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.CustomFeatureGatesFluent<A>{
  public CustomFeatureGatesFluentImpl() {
  }
  public CustomFeatureGatesFluentImpl(io.fabric8.openshift.api.model.CustomFeatureGates instance) {
    this.withDisabled(instance.getDisabled()); 
    this.withEnabled(instance.getEnabled()); 
  }
  private java.util.List<java.lang.String> disabled = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> enabled = new java.util.ArrayList<java.lang.String>();
  public A addToDisabled(java.lang.Integer index,java.lang.String item) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    this.disabled.add(index, item);
    return (A)this;
  }
  public A setToDisabled(java.lang.Integer index,java.lang.String item) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    this.disabled.set(index, item); return (A)this;
  }
  public A addToDisabled(java.lang.String... items) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A addAllToDisabled(java.util.Collection<java.lang.String> items) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A removeFromDisabled(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public A removeAllFromDisabled(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getDisabled() {
    return this.disabled;
  }
  public java.lang.String getDisabled(java.lang.Integer index) {
    return this.disabled.get(index);
  }
  public java.lang.String getFirstDisabled() {
    return this.disabled.get(0);
  }
  public java.lang.String getLastDisabled() {
    return this.disabled.get(disabled.size() - 1);
  }
  public java.lang.String getMatchingDisabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabled) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingDisabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabled) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDisabled(java.util.List<java.lang.String> disabled) {
    if (disabled != null) {this.disabled = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : disabled){this.addToDisabled(item);}} else { this.disabled = null;} return (A) this;
  }
  public A withDisabled(java.lang.String... disabled) {
    if (this.disabled != null) {this.disabled.clear();}
    if (disabled != null) {for (java.lang.String item :disabled){ this.addToDisabled(item);}} return (A) this;
  }
  public java.lang.Boolean hasDisabled() {
    return disabled != null && !disabled.isEmpty();
  }
  public A addNewDisabled(java.lang.String arg0) {
    return (A)addToDisabled(new String(arg0));
  }
  public A addToEnabled(java.lang.Integer index,java.lang.String item) {
    if (this.enabled == null) {this.enabled = new java.util.ArrayList<java.lang.String>();}
    this.enabled.add(index, item);
    return (A)this;
  }
  public A setToEnabled(java.lang.Integer index,java.lang.String item) {
    if (this.enabled == null) {this.enabled = new java.util.ArrayList<java.lang.String>();}
    this.enabled.set(index, item); return (A)this;
  }
  public A addToEnabled(java.lang.String... items) {
    if (this.enabled == null) {this.enabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.enabled.add(item);} return (A)this;
  }
  public A addAllToEnabled(java.util.Collection<java.lang.String> items) {
    if (this.enabled == null) {this.enabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.enabled.add(item);} return (A)this;
  }
  public A removeFromEnabled(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
  }
  public A removeAllFromEnabled(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getEnabled() {
    return this.enabled;
  }
  public java.lang.String getEnabled(java.lang.Integer index) {
    return this.enabled.get(index);
  }
  public java.lang.String getFirstEnabled() {
    return this.enabled.get(0);
  }
  public java.lang.String getLastEnabled() {
    return this.enabled.get(enabled.size() - 1);
  }
  public java.lang.String getMatchingEnabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: enabled) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingEnabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: enabled) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withEnabled(java.util.List<java.lang.String> enabled) {
    if (enabled != null) {this.enabled = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : enabled){this.addToEnabled(item);}} else { this.enabled = null;} return (A) this;
  }
  public A withEnabled(java.lang.String... enabled) {
    if (this.enabled != null) {this.enabled.clear();}
    if (enabled != null) {for (java.lang.String item :enabled){ this.addToEnabled(item);}} return (A) this;
  }
  public java.lang.Boolean hasEnabled() {
    return enabled != null && !enabled.isEmpty();
  }
  public A addNewEnabled(java.lang.String arg0) {
    return (A)addToEnabled(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomFeatureGatesFluentImpl that = (CustomFeatureGatesFluentImpl) o;
    if (disabled != null ? !disabled.equals(that.disabled) :that.disabled != null) return false;
    if (enabled != null ? !enabled.equals(that.enabled) :that.enabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disabled,  enabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/CustomFeatureGatesFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CustomFeatureGatesFluentImpl<A extends io.fabric8.openshift.api.model.CustomFeatureGatesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.CustomFeatureGatesFluent<A>{
  public CustomFeatureGatesFluentImpl() {
  }
  public CustomFeatureGatesFluentImpl(io.fabric8.openshift.api.model.CustomFeatureGates instance) {
    this.withDisabled(instance.getDisabled()); 
    this.withEnabled(instance.getEnabled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> disabled = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> enabled = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToDisabled(java.lang.Integer index,java.lang.String item) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    this.disabled.add(index, item);
    return (A)this;
  }
  public A setToDisabled(java.lang.Integer index,java.lang.String item) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    this.disabled.set(index, item); return (A)this;
  }
  public A addToDisabled(java.lang.String... items) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A addAllToDisabled(java.util.Collection<java.lang.String> items) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A removeFromDisabled(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public A removeAllFromDisabled(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getDisabled() {
    return this.disabled;
  }
  public java.lang.String getDisabled(java.lang.Integer index) {
    return this.disabled.get(index);
  }
  public java.lang.String getFirstDisabled() {
    return this.disabled.get(0);
  }
  public java.lang.String getLastDisabled() {
    return this.disabled.get(disabled.size() - 1);
  }
  public java.lang.String getMatchingDisabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabled) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingDisabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabled) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDisabled(java.util.List<java.lang.String> disabled) {
    if (disabled != null) {this.disabled = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : disabled){this.addToDisabled(item);}} else { this.disabled = null;} return (A) this;
  }
  public A withDisabled(java.lang.String... disabled) {
    if (this.disabled != null) {this.disabled.clear();}
    if (disabled != null) {for (java.lang.String item :disabled){ this.addToDisabled(item);}} return (A) this;
  }
  public java.lang.Boolean hasDisabled() {
    return disabled != null && !disabled.isEmpty();
  }
  public A addNewDisabled(java.lang.String arg0) {
    return (A)addToDisabled(new String(arg0));
  }
  public A addToEnabled(java.lang.Integer index,java.lang.String item) {
    if (this.enabled == null) {this.enabled = new java.util.ArrayList<java.lang.String>();}
    this.enabled.add(index, item);
    return (A)this;
  }
  public A setToEnabled(java.lang.Integer index,java.lang.String item) {
    if (this.enabled == null) {this.enabled = new java.util.ArrayList<java.lang.String>();}
    this.enabled.set(index, item); return (A)this;
  }
  public A addToEnabled(java.lang.String... items) {
    if (this.enabled == null) {this.enabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.enabled.add(item);} return (A)this;
  }
  public A addAllToEnabled(java.util.Collection<java.lang.String> items) {
    if (this.enabled == null) {this.enabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.enabled.add(item);} return (A)this;
  }
  public A removeFromEnabled(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
  }
  public A removeAllFromEnabled(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getEnabled() {
    return this.enabled;
  }
  public java.lang.String getEnabled(java.lang.Integer index) {
    return this.enabled.get(index);
  }
  public java.lang.String getFirstEnabled() {
    return this.enabled.get(0);
  }
  public java.lang.String getLastEnabled() {
    return this.enabled.get(enabled.size() - 1);
  }
  public java.lang.String getMatchingEnabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: enabled) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingEnabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: enabled) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withEnabled(java.util.List<java.lang.String> enabled) {
    if (enabled != null) {this.enabled = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : enabled){this.addToEnabled(item);}} else { this.enabled = null;} return (A) this;
  }
  public A withEnabled(java.lang.String... enabled) {
    if (this.enabled != null) {this.enabled.clear();}
    if (enabled != null) {for (java.lang.String item :enabled){ this.addToEnabled(item);}} return (A) this;
  }
  public java.lang.Boolean hasEnabled() {
    return enabled != null && !enabled.isEmpty();
  }
  public A addNewEnabled(java.lang.String arg0) {
    return (A)addToEnabled(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomFeatureGatesFluentImpl that = (CustomFeatureGatesFluentImpl) o;
    if (disabled != null ? !disabled.equals(that.disabled) :that.disabled != null) return false;
    if (enabled != null ? !enabled.equals(that.enabled) :that.enabled != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disabled,  enabled,  additionalProperties,  super.hashCode());
  }
  
}
